@@ -14,6 +14,8 @@
 #include "cl_FF.h"
 #include "cl_DS.h"
 
+namespace cln {
+
 const cl_FF cl_LF_to_FF (const cl_LF& x)
 {
 	// x entpacken:
@@ -44,8 +46,10 @@ const cl_FF cl_LF_to_FF (const cl_LF& x)
 	  { mant = mant >> shiftcount;
 	    mant = mant+1;
 	    if (mant >= bit(FF_mant_len+1))
-	      // berlauf durchs Runden
+	      // Überlauf durchs Runden
 	      { mant = mant>>1; exp = exp+1; } // Mantisse rechts schieben
 	  }
 	return encode_FF(sign,exp,mant);
 }
+
+}  // namespace cln
