@@ -13,10 +13,9 @@
 
 namespace cln {
 
-MAYBE_INLINE
-cl_boolean zerop (const cl_LF& x)
+CL_INLINE bool CL_INLINE_DECL(zerop) (const cl_LF& x)
 {
-	return (cl_boolean) (TheLfloat(x)->expo == 0);
+	return TheLfloat(x)->expo == 0;
 }
 
 }  // namespace cln
