@@ -9,13 +9,9 @@
 
 // Implementation.
 
-#include "cln/abort.h"
-
-#undef MAYBE_INLINE2
-#define MAYBE_INLINE2 inline
+#include "cl_inline2.h"
 #include "cl_LF_precision.cc"
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_LF_exponent.cc"
 
 namespace cln {
@@ -26,13 +22,13 @@ const cl_LF cl_LF_shortenwith (const cl_LF& x, const cl_LF& y)
 	// x = 0.0 -> Precision egal, return x.
 	// ex := float_exponent(x), dx := float_digits(x), 1 ulp(x) = 2^(ex-dx).
 	// ey := float_exponent(y).
-	// Falls ex-dx < ey, x von Precision dx auf ex-ey verkrzen.
-	var sintL ey = float_exponent(y);
-	var sintL ex = float_exponent(x);
-	var uintL dx = float_precision(x);
+	// Falls ex-dx < ey, x von Precision dx auf ex-ey verkürzen.
+	var sintE ey = float_exponent_inline(y);
+	var sintE ex = float_exponent_inline(x);
+	var uintC dx = float_precision_inline(x);
 	if (dx==0) // zerop(x) ?
 		return x;
-	var sintL ulpx = ex - dx;
+	var sintE ulpx = ex - dx;
 	if ((ex<0 && ulpx>=0) // underflow?
 	    || (ulpx < ey)
 	   ) {	// Now ex-dx < ey, hence ex-ey < dx.
