@@ -13,10 +13,9 @@
 
 namespace cln {
 
-MAYBE_INLINE
-cl_boolean zerop (const cl_SF& x)
+CL_INLINE bool CL_INLINE_DECL(zerop) (const cl_SF& x)
 {
-	return (cl_boolean) (x.word == make_SF_word(0,0,0));
+	return x.word == make_SF_word(0,0,0);
 }
 
 }  // namespace cln
