@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
@@ -12,16 +12,18 @@
 #include "cl_I.h"
 #include "cl_DS.h"
 
+namespace cln {
+
 const cl_I operator- (const cl_I& x)
 {
 	if (fixnump(x)) {
-		#if (cl_value_len < intLsize)
-		return L_to_I(- FN_to_L(x));
+		#if (cl_value_len < intVsize)
+		return V_to_I(- FN_to_V(x));
 		#elif (cl_word_size==64)
 		return Q_to_I(- FN_to_Q(x));
-		#else // (cl_value_len == intLsize)
-		var sint32 xhi = sign_of(FN_to_L(x));
-		var uint32 xlo = FN_to_L(x);
+		#elif (intVsize==32) // && (cl_value_len == intVsize)
+		var sint32 xhi = sign_of(FN_to_V(x));
+		var uint32 xlo = FN_to_V(x);
 		return L2_to_I(-xhi-(xlo!=0),-xlo);
 		#endif
 	} else {
@@ -41,3 +43,5 @@ const cl_I operator- (const cl_I& x)
           return DS_to_I(MSDptr,len); // DS wieder zum Integer machen
 	}
 }
+
+}  // namespace cln
