@@ -18,7 +18,7 @@ cl_read_flags cl_RA_read_flags = {
 	syntax_rational,
 	lsyntax_all,
 	10,
-	{ float_format_ffloat, float_format_lfloat_min, cl_true }
+	{ float_format_ffloat, float_format_lfloat_min, true }
 };
 
 cl_RA::cl_RA (const char * string)
