@@ -11,8 +11,7 @@
 
 namespace cln {
 
-MAYBE_INLINE
-const cl_R tanh (const cl_R& x)
+CL_INLINE const cl_R CL_INLINE_DECL(tanh) (const cl_R& x)
 {
 // Methode:
 // (/ (sinh x) (cosh x))
